#!/usr/bin/env python

import sys
import getopt
from xml.dom import minidom
from xml.dom import Node

#
# If you have installed IPython you can uncomment and use the following.
# IPython is available from http://www-hep.colorado.edu/~fperez/ipython.
#
#from IPython.Shell import IPythonShellEmbed
#IPShell = IPythonShellEmbed('-nosep',
#    banner = 'Entering interpreter.  Ctrl-D to exit.',
#    exit_msg = 'Leaving Interpreter.')

# Use the following line when you want to drop into the IPython shell:
#    IPShell(vars(), '<a msg>')

#
# Support/utility functions.
#

def showIndent(outfile, level):
    for idx in range(level):
        outfile.write('    ')


#
# Data representation classes.
#

class definitions:
    def __init__(self, swig_functionWrapper=None, swig_variableWrapper=None, swig_classWrapper=None):
        if swig_functionWrapper is None:
            self.swig_functionWrapper = []
        else:
            self.swig_functionWrapper = swig_functionWrapper
        if swig_variableWrapper is None:
            self.swig_variableWrapper = []
        else:
            self.swig_variableWrapper = swig_variableWrapper
        if swig_classWrapper is None:
            self.swig_classWrapper = []
        else:
            self.swig_classWrapper = swig_classWrapper
    def getSwig_functionwrapper(self): return self.swig_functionWrapper
    def addSwig_functionwrapper(self, swig_functionWrapper): self.swig_functionWrapper.append(swig_functionWrapper)
    def getSwig_variablewrapper(self): return self.swig_variableWrapper
    def addSwig_variablewrapper(self, swig_variableWrapper): self.swig_variableWrapper.append(swig_variableWrapper)
    def getSwig_classwrapper(self): return self.swig_classWrapper
    def addSwig_classwrapper(self, swig_classWrapper): self.swig_classWrapper.append(swig_classWrapper)
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<definitions>\n')
        level += 1
        for swig_functionWrapper in self.swig_functionWrapper:
            swig_functionWrapper.export(outfile, level)
        for swig_variableWrapper in self.swig_variableWrapper:
            swig_variableWrapper.export(outfile, level)
        for swig_classWrapper in self.swig_classWrapper:
            swig_classWrapper.export(outfile, level)
        level -= 1
        showIndent(outfile, level)
        outfile.write('</definitions>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:functionWrapper':
                obj = functionWrapper()
                obj.build(child)
                self.swig_functionWrapper.append(obj)
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:variableWrapper':
                obj = variableWrapper()
                obj.build(child)
                self.swig_variableWrapper.append(obj)
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:classWrapper':
                obj = classWrapper()
                obj.build(child)
                self.swig_classWrapper.append(obj)


class functionWrapper:
    def __init__(self, swig_functionName='', swig_functionSymName='', swig_returnType='', swig_swigReturnType='', swig_parameters=None):
        self.swig_functionName = swig_functionName
        self.swig_functionSymName = swig_functionSymName
        self.swig_returnType = swig_returnType
        self.swig_swigReturnType = swig_swigReturnType
        self.swig_parameters = swig_parameters
    def getSwig_functionname(self): return self.swig_functionName
    def setSwig_functionname(self, swig_functionName): self.swig_functionName = swig_functionName
    def getSwig_functionsymname(self): return self.swig_functionSymName
    def setSwig_functionsymname(self, swig_functionSymName): self.swig_functionSymName = swig_functionSymName
    def getSwig_returntype(self): return self.swig_returnType
    def setSwig_returntype(self, swig_returnType): self.swig_returnType = swig_returnType
    def getSwig_swigreturntype(self): return self.swig_swigReturnType
    def setSwig_swigreturntype(self, swig_swigReturnType): self.swig_swigReturnType = swig_swigReturnType
    def getSwig_parameters(self): return self.swig_parameters
    def setSwig_parameters(self, swig_parameters): self.swig_parameters = swig_parameters
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<functionWrapper>\n')
        level += 1
        showIndent(outfile, level)
        outfile.write('<swig_functionName>%s</swig_functionName>\n' % self.getSwig_functionname())
        showIndent(outfile, level)
        outfile.write('<swig_functionSymName>%s</swig_functionSymName>\n' % self.getSwig_functionsymname())
        showIndent(outfile, level)
        outfile.write('<swig_returnType>%s</swig_returnType>\n' % self.getSwig_returntype())
        showIndent(outfile, level)
        outfile.write('<swig_swigReturnType>%s</swig_swigReturnType>\n' % self.getSwig_swigreturntype())
        if self.swig_parameters:
            self.swig_parameters.export(outfile, level)
        level -= 1
        showIndent(outfile, level)
        outfile.write('</functionWrapper>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:functionName':
                swig_functionName = ''
                for text in child.childNodes:
                    swig_functionName += text.nodeValue
                self.swig_functionName = swig_functionName
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:functionSymName':
                swig_functionSymName = ''
                for text in child.childNodes:
                    swig_functionSymName += text.nodeValue
                self.swig_functionSymName = swig_functionSymName
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:returnType':
                swig_returnType = ''
                for text in child.childNodes:
                    swig_returnType += text.nodeValue
                self.swig_returnType = swig_returnType
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:swigReturnType':
                swig_swigReturnType = ''
                for text in child.childNodes:
                    swig_swigReturnType += text.nodeValue
                self.swig_swigReturnType = swig_swigReturnType
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:parameters':
                obj = functionParameters()
                obj.build(child)
                self.setSwig_parameters(obj)


class variableWrapper:
    def __init__(self, swig_variableName='', swig_variableSymName='', swig_type='', swig_swigType=''):
        self.swig_variableName = swig_variableName
        self.swig_variableSymName = swig_variableSymName
        self.swig_type = swig_type
        self.swig_swigType = swig_swigType
    def getSwig_variablename(self): return self.swig_variableName
    def setSwig_variablename(self, swig_variableName): self.swig_variableName = swig_variableName
    def getSwig_variablesymname(self): return self.swig_variableSymName
    def setSwig_variablesymname(self, swig_variableSymName): self.swig_variableSymName = swig_variableSymName
    def getSwig_type(self): return self.swig_type
    def setSwig_type(self, swig_type): self.swig_type = swig_type
    def getSwig_swigtype(self): return self.swig_swigType
    def setSwig_swigtype(self, swig_swigType): self.swig_swigType = swig_swigType
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<variableWrapper>\n')
        level += 1
        showIndent(outfile, level)
        outfile.write('<swig_variableName>%s</swig_variableName>\n' % self.getSwig_variablename())
        showIndent(outfile, level)
        outfile.write('<swig_variableSymName>%s</swig_variableSymName>\n' % self.getSwig_variablesymname())
        showIndent(outfile, level)
        outfile.write('<swig_type>%s</swig_type>\n' % self.getSwig_type())
        showIndent(outfile, level)
        outfile.write('<swig_swigType>%s</swig_swigType>\n' % self.getSwig_swigtype())
        level -= 1
        showIndent(outfile, level)
        outfile.write('</variableWrapper>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:variableName':
                swig_variableName = ''
                for text in child.childNodes:
                    swig_variableName += text.nodeValue
                self.swig_variableName = swig_variableName
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:variableSymName':
                swig_variableSymName = ''
                for text in child.childNodes:
                    swig_variableSymName += text.nodeValue
                self.swig_variableSymName = swig_variableSymName
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:type':
                swig_type = ''
                for text in child.childNodes:
                    swig_type += text.nodeValue
                self.swig_type = swig_type
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:swigType':
                swig_swigType = ''
                for text in child.childNodes:
                    swig_swigType += text.nodeValue
                self.swig_swigType = swig_swigType


class classWrapper:
    def __init__(self, swig_className='', swig_functionWrapper=None, swig_variableWrapper=None):
        self.swig_className = swig_className
        if swig_functionWrapper is None:
            self.swig_functionWrapper = []
        else:
            self.swig_functionWrapper = swig_functionWrapper
        if swig_variableWrapper is None:
            self.swig_variableWrapper = []
        else:
            self.swig_variableWrapper = swig_variableWrapper
    def getSwig_classname(self): return self.swig_className
    def setSwig_classname(self, swig_className): self.swig_className = swig_className
    def getSwig_functionwrapper(self): return self.swig_functionWrapper
    def addSwig_functionwrapper(self, swig_functionWrapper): self.swig_functionWrapper.append(swig_functionWrapper)
    def getSwig_variablewrapper(self): return self.swig_variableWrapper
    def addSwig_variablewrapper(self, swig_variableWrapper): self.swig_variableWrapper.append(swig_variableWrapper)
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<classWrapper>\n')
        level += 1
        showIndent(outfile, level)
        outfile.write('<swig_className>%s</swig_className>\n' % self.getSwig_classname())
        for swig_functionWrapper in self.swig_functionWrapper:
            swig_functionWrapper.export(outfile, level)
        for swig_variableWrapper in self.swig_variableWrapper:
            swig_variableWrapper.export(outfile, level)
        level -= 1
        showIndent(outfile, level)
        outfile.write('</classWrapper>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:className':
                swig_className = ''
                for text in child.childNodes:
                    swig_className += text.nodeValue
                self.swig_className = swig_className
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:functionWrapper':
                obj = functionWrapper()
                obj.build(child)
                self.swig_functionWrapper.append(obj)
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:variableWrapper':
                obj = variableWrapper()
                obj.build(child)
                self.swig_variableWrapper.append(obj)


class functionParameters:
    def __init__(self, swig_parameterCount=-1, swig_parameter=None):
        self.swig_parameterCount = swig_parameterCount
        if swig_parameter is None:
            self.swig_parameter = []
        else:
            self.swig_parameter = swig_parameter
    def getSwig_parametercount(self): return self.swig_parameterCount
    def setSwig_parametercount(self, swig_parameterCount): self.swig_parameterCount = swig_parameterCount
    def getSwig_parameter(self): return self.swig_parameter
    def addSwig_parameter(self, swig_parameter): self.swig_parameter.append(swig_parameter)
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<functionParameters>\n')
        level += 1
        showIndent(outfile, level)
        outfile.write('<swig_parameterCount>%d</swig_parameterCount>\n' % self.getSwig_parametercount())
        for swig_parameter in self.swig_parameter:
            swig_parameter.export(outfile, level)
        level -= 1
        showIndent(outfile, level)
        outfile.write('</functionParameters>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:parameterCount':
                if child.firstChild:
                    sval = child.firstChild.nodeValue
                    try:
                        ival = int(sval)
                    except ValueError:
                        showError('*** requires integer -- %s' % child.toxml())
                    self.swig_parameterCount = ival
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:parameter':
                obj = functionParameter()
                obj.build(child)
                self.swig_parameter.append(obj)


class functionParameter:
    def __init__(self, swig_parameterName='', swig_parameterType=''):
        self.swig_parameterName = swig_parameterName
        self.swig_parameterType = swig_parameterType
    def getSwig_parametername(self): return self.swig_parameterName
    def setSwig_parametername(self, swig_parameterName): self.swig_parameterName = swig_parameterName
    def getSwig_parametertype(self): return self.swig_parameterType
    def setSwig_parametertype(self, swig_parameterType): self.swig_parameterType = swig_parameterType
    def export(self, outfile, level):
        showIndent(outfile, level)
        outfile.write('<functionParameter>\n')
        level += 1
        showIndent(outfile, level)
        outfile.write('<swig_parameterName>%s</swig_parameterName>\n' % self.getSwig_parametername())
        showIndent(outfile, level)
        outfile.write('<swig_parameterType>%s</swig_parameterType>\n' % self.getSwig_parametertype())
        level -= 1
        showIndent(outfile, level)
        outfile.write('</functionParameter>\n')
    def build(self, node):
        attrs = node.attributes
        for child in node.childNodes:
            if child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:parameterName':
                swig_parameterName = ''
                for text in child.childNodes:
                    swig_parameterName += text.nodeValue
                self.swig_parameterName = swig_parameterName
            elif child.nodeType == Node.ELEMENT_NODE and \
                child.nodeName == 'swig:parameterType':
                swig_parameterType = ''
                for text in child.childNodes:
                    swig_parameterType += text.nodeValue
                self.swig_parameterType = swig_parameterType


USAGE_TEXT = """
Usage: python <Parser>.py <in_xml_file>
"""

def usage():
    print USAGE_TEXT
    sys.exit(-1)


def parse(inFileName):
    doc = minidom.parse(inFileName)
    rootNode = doc.childNodes[0]
    rootObj = definitions()
    rootObj.build(rootNode)
    rootObj.export(sys.stdout, 0)
    return rootObj


def main():
    args = sys.argv[1:]
    if len(args) != 1:
        usage()
    parse(args[0])


if __name__ == '__main__':
    main()
    #import pdb
    #pdb.run('main()')

